==> qgis_3.22.16+dfsg.orig.tar.xz: qgis-3.22.16/src/providers/postgres/raster/qgspostgresrastertemporalsettingswidget.h <==
/***************************************************************************
      qgspostgresrastertemporalsettingswidget.h
      ------------------
    begin                : March 2021
    copyright            : (C) 2021 by Nyall Dawson
    email                : nyall dot dawson at gmail dot com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef QGSPOSTGRESRASTERTEMPORALSETTINGSWIDGET_H
#define QGSPOSTGRESRASTERTEMPORALSETTINGSWIDGET_H

#include "ui_qgspostgresrastertemporalsettingswidgetbase.h"
#include "qgsmaplayerconfigwidget.h"
#include "qgsmaplayerconfigwidgetfactory.h"

class QgsRasterLayer;

class QgsPostgresRasterTemporalSettingsWidget : public QgsMapLayerConfigWidget, private Ui::QgsPostgresRasterTemporalSettingsWidgetBase
{
    Q_OBJECT

  public:
    QgsPostgresRasterTemporalSettingsWidget( QgsMapLayer *layer, QgsMapCanvas *canvas, QWidget *parent = nullptr );

    void syncToLayer( QgsMapLayer *layer ) override;
    void apply() override;
  private slots:

  private:

    QgsRasterLayer *mRasterLayer = nullptr;

};

class QgsPostgresRasterTemporalSettingsConfigWidgetFactory : public QgsMapLayerConfigWidgetFactory
{
  public:
    bool supportLayerPropertiesDialog() const override;
    bool supportsLayer( QgsMapLayer *layer ) const override;
    ParentPage parentPage() const override;
    QgsMapLayerConfigWidget *createWidget( QgsMapLayer *layer, QgsMapCanvas *canvas, bool dockWidget = true, QWidget *parent = nullptr ) const override;

};

#endif // QGSPOSTGRESRASTERTEMPORALSETTINGSWIDGET_H

==> qgis_3.34.4+dfsg.orig.tar.xz: qgis-3.34.4/src/providers/postgres/raster/qgspostgresrastertemporalsettingswidget.h <==
/***************************************************************************
      qgspostgresrastertemporalsettingswidget.h
      ------------------
    begin                : March 2021
    copyright            : (C) 2021 by Nyall Dawson
    email                : nyall dot dawson at gmail dot com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef QGSPOSTGRESRASTERTEMPORALSETTINGSWIDGET_H
#define QGSPOSTGRESRASTERTEMPORALSETTINGSWIDGET_H

#include "ui_qgspostgresrastertemporalsettingswidgetbase.h"
#include "qgsmaplayerconfigwidget.h"
#include "qgsmaplayerconfigwidgetfactory.h"

class QgsRasterLayer;

class QgsPostgresRasterTemporalSettingsWidget : public QgsMapLayerConfigWidget, private Ui::QgsPostgresRasterTemporalSettingsWidgetBase
{
    Q_OBJECT

  public:
    QgsPostgresRasterTemporalSettingsWidget( QgsMapLayer *layer, QgsMapCanvas *canvas, QWidget *parent = nullptr );

    void syncToLayer( QgsMapLayer *layer ) final;
    void apply() override;
  private slots:

  private:

    QgsRasterLayer *mRasterLayer = nullptr;

};

class QgsPostgresRasterTemporalSettingsConfigWidgetFactory : public QgsMapLayerConfigWidgetFactory
{
  public:
    bool supportLayerPropertiesDialog() const override;
    bool supportsLayer( QgsMapLayer *layer ) const override;
    ParentPage parentPage() const override;
    QgsMapLayerConfigWidget *createWidget( QgsMapLayer *layer, QgsMapCanvas *canvas, bool dockWidget = true, QWidget *parent = nullptr ) const override;

};

#endif // QGSPOSTGRESRASTERTEMPORALSETTINGSWIDGET_H
